// TODO: max number of lights needs to be available to the engine
const int MAX_NUM_LIGHTS = 4;

struct LightProps {
    vec3 color;
};

attribute vec4 a_position;
attribute vec3 a_normal;
attribute vec2 a_texCoord;

uniform mat4 u_modelViewMat;
uniform mat4 u_projMat;
uniform mat3 u_normalMat;

uniform int  u_numLights;
uniform vec3 u_lightPos[MAX_NUM_LIGHTS];
uniform LightProps u_lightProps[MAX_NUM_LIGHTS];

varying vec2 v_texCoord;

// light contribution from all lights added together
varying vec3 v_totalLight; 

void main() {
    v_texCoord = a_texCoord;

    vec3 vertexVec = vec3(u_modelViewMat * a_position);

    vec3 normal = normalize(u_normalMat * a_normal);

    vec3 totalLight = vec3(0, 0, 0);

    for (int i = 0; i < u_numLights; i++) {
        vec3 lightDir = normalize(vec3(u_lightPos[i] - vertexVec));
        float lambert = dot(normal, lightDir);

        if (lambert > 0.0) {
            totalLight += lambert * u_lightProps[i].color;
        }
    }

    v_totalLight = totalLight;

    gl_Position = u_projMat * u_modelViewMat * a_position;
}
